==> flatnuke_2.7.orig.tar.gz: flatnuke-2.7/languages/fd+lang/fd+de.php <==
<?
/**
/* FD+:German Translation
/*
/* German language file for FD+0.7
/*
/* @author Aldo Boccacci <zorba_@tin.it> Author
/* @author Bjoern Splinter <Insites@gmail.com> Translator
*/

//Benutzerinterface
define("_FDNAME","Name");
define("_FDSIZE","Gr&ouml;sse");
define("_FDDATE","Herausgekommen&nbsp;am");
define("_FDVERSION", "Version");
define("_FDDESC","Beschreibung");
define("_FDHITS","Hits");
define("_FDDOWNLOAD","HERUNTERLADEN!");
define("_FDSTAT","Downloadstatistik");
define("_FDSTATTITLE","Downloadstatistik&nbsp;ansehen");
define("_FDDOWNLOADFILE","Datei&nbsp;herunterladen:&nbsp;");
define("_FDARCHIVEDIR","Archivverzeichnis");
/*define("_GOTOSECTION","Sektion&nbsp;ansehen");*/
define("_FDUPLOADER","Hochgeladen&nbsp;von");
define("_FDUPLOADERTITLE","Userprofil ansehen");
//Datumsformat
define("_FDDATEFORMAT","d/m/Y H:i:s");

//gpg signatur
define("_FDGPGSIGN","GPG&nbsp;Signatur");
define("_FDGPGSIGNTITLE","GPG&nbsp;Signatur&nbsp;dieser&nbsp;Datei&nbsp;herunterladen:&nbsp;");
define("_FDDELETESIG","Signatur&nbsp;l&ouml;schen");

//Administration
define("_FDARCHIVE","Archivieren");
define("_FDRESTORE","Wiederherstellen");
define("_FDEDIT","Bearbeiten");
define("_FDDELETE","L&ouml;schen");
define("_FDHIDE","Verstecken");
define("_FDSHOW","Zeigen");
define("_FDRENAME","Umbenennen");
define("_FDADDFILE","Datei&nbsp;hinzuf&uuml;gen");

define("_FDARCHIVETITLE","Datei&nbsp;archivieren:&nbsp;");
define("_FDRESTORETITLE","Datei&nbsp;wiederherstellen:&nbsp;");
define("_FDEDITTITLE","Dateititel&nbsp;bearbeiten:&nbsp;");
define("_FDDELETETITLE","Datei&nbsp;l&ouml;schen:&nbsp;");
define("_FDHIDETITLE","Datei&nbsp;verstecken:&nbsp;");
define("_FDSHOWTITLE","Datei&nbsp;sichtbar&nbsp;machen:&nbsp;");
define("_FDRENAMETITLE","Datei&nbsp;umbenennen:&nbsp;");
define("_FDADDFILETITLE","Datei&nbsp;zu&nbsp;dieser&nbsp;Sektion&nbsp;hinzuf&uuml;gen.");

define("_FDBACK","Zur&uuml;ck");

//Edit/Add file
define("_FDRETURN","Return");
define("_FDEDITDESC","Dateibeschreibung&nbsp;bearbeiten:&nbsp;");
define("_FDEDITHEADER","Auf&nbsp;dieser&nbsp;Seite&nbsp;kannst&nbsp;Du&nbsp;die&nbsp;Beschreibung&nbsp;dieses&nbsp;Eintrags&nbsp;&auml;ndern.&nbsp;&Auml;nderungen&nbsp;werden&nbsp;gespeichert&nbsp;in:&nbsp;");
define("_FDEDITFOOTER","Du&nbsp;kannst&nbsp;auch&nbsp;die&nbsp;Datei&nbsp;selbst&nbsp;&auml;ndern.<br />Die&nbsp;neue&nbsp;Datei&nbsp;kann&nbsp;einen&nbsp;anderen&nbsp;Namen&nbsp;haben,&nbsp;fd+&nbsp;wird&nbsp;die&nbsp;zugeh&ouml;rige&nbsp;&nbsp;\".description\"&nbsp;automatisch&nbsp;&auml;ndern<br />&nbsp;und&nbsp;die&nbsp;alte&nbsp;Datei&nbsp;l&ouml;schen.");
define("_FDEDITSAVE", "&Auml;nderung&nbsp;speichern");
define("_FDEDITDONE", "&Auml;nderungen&nbsp;gespeichert");

//Rename File
define("_FDRENAMECHOOSE","Neuen&nbsp;Namen&nbsp;ausw&auml;hlen:&nbsp;");
define("_FDRENAMEEXTLIMIT","Die&nbsp;Dateierweiterung&nbsp;kann&nbsp;nicht&nbsp;ge&auml;ndert&nbsp;werden!.");
define("_FDRENAMEFILE","Die&nbsp;Datei&nbsp;");
define("_FDRENAMENOFD","ist&nbsp;keine&nbsp;FD+-Datei.");
define("_FDRENAMEOK","Umbenennen&nbsp;erfolgreich.");
define("_FDRENAMENOTCHANGED","Name&nbsp;nicht&nbsp;ge&auml;ndert.");
define("_FDRENAMEEXISTS1","Eine&nbsp;Datei&nbsp;mit&nbsp;Namen");
define("_FDRENAMEEXISTS2","ist&nbsp;im&nbsp;Verzeichnis&nbsp;bereits&nbsp;vorhanden!");
define("_FDRENAMECHANGENAME","Anderen&nbsp;Namen&nbsp;angeben.");
define("_FDRENAMEALERT","<b>ACHTUNG!</b>&nbsp;Datei&nbsp;kann&nbsp;nicht&nbsp;umbenannt&nbsp;werden");

//Delete file
define("_FDDELSURE","Bist&nbsp;Du&nbsp;sicher,&nbsp;dass&nbsp;Du&nbsp;folgende&nbsp;Dateien&nbsp;l&ouml;schen&nbsp;willst:&nbsp;");
define("_FDDEL", "L&ouml;schen");
define("_FDCANC", "Abbrechen");
define("_FDDELOK","Dateien&nbsp;gel&ouml;scht:&nbsp;");
define("_FDAND","und");

//Archive file
define("_FDARCHIVEOK","Datei&nbsp;archiviert.");
define("_FDARCHIVEGO","Zum&nbsp;Archivverzeichnis&nbsp;gehen.");
define("_FDRESTOREOK","Datei&nbsp;erfolgreich&nbsp;wiederhergestellt");
define("_FDARCHIVERETURN","zur&uuml;ck&nbsp;zur&nbsp;vorherigen&nbsp;Sektion");
define("_GOTOARCHIVEDIR","Zur&nbsp;Archivsektion&nbsp;gehen");

//Add file
define("_FDADDWHERE","Neue&nbsp;Datei&nbsp;zum&nbsp;Verzeichnis&nbsp;hinzuf&uuml;gen:&nbsp;");
define("_FDADDHEADER","Auf&nbsp;dieser&nbsp;Seite&nbsp;kannst&nbsp;Du&nbsp;eine&nbsp;neue&nbsp;Datei&nbsp;zum&nbsp;Verzeichnis&nbsp;hinzuf&uuml;gen");
define("_FDADDFOOTER","Eine&nbsp;Datei&nbsp;auf&nbsp;deinem&nbsp;Rechner&nbsp;ausw&auml;hlen.");
define("_NOTVALIDEXT","Die&nbsp;Erweiterung&nbsp;dieser&nbsp;Datei&nbsp;wird&nbsp;von&nbsp;FD+&nbsp;nicht&nbsp;unterst&uuml;tzt.&nbsp;Bitte&nbsp;f&uuml;ge&nbsp;zuerst&nbsp;diese&nbsp;Erweiterung&nbsp;zur&nbsp;Variable&nbsp;&#036;extensions&nbsp;in&nbsp;der&nbsp;Datei&nbsp;\"fd+.php\"&nbsp;hinzu");

//save file
define("_FDSAVESIZE","<b>ACHTUNG!</b>&nbsp;Dateigr&ouml;sse&nbsp;ist&nbsp;");

//move file
define("_FDMOVE","Verschieben");
define("_FDMOVEFILE","Datei&nbsp;verschieben&nbsp;");
define("_FDMOVEFILESECTION","&nbsp;nach&nbsp;Sektion");
define("_FDMOVELINK","(zum&nbsp;Verschieben&nbsp;auf&nbsp;die&nbsp;Verkn&uuml;pfung&nbsp;klicken)");
define("_FDMOVECONFIRM","Datei&nbsp;verschieben&nbsp;");
define("_FDMOVEFAIL","Verschieben&nbsp;der&nbsp;Datei&nbsp;nicht&nbsp;m&ouml;glich&nbsp;");
define("_FDMOVESUCCESS","erfolgreich&nbsp;verschoben");
define("_FDMOVETITLE","Folgende&nbsp;Datei&nbsp;verschieben:&nbsp;");
define("_FDDIR","Das&nbsp;Verzeichnis");


//creazione cartelle
define("_FDCREATESECTDOWNLOAD","Downloadsektion&nbsp;erzeugen");
define("_FDCREATESECT","Sektion&nbsp;erzeugen");
define("_FDCREATESECTOK","erfolgreich&nbsp;erzeugt!");
define("_FDCREATEONLYDIR","Sektion&nbsp;erzeugt,&nbsp;Datei&nbsp;section.php&nbsp;konnte&nbsp;aber&nbsp;nicht&nbsp;erstellt&nbsp;werden!");
define("_FDCREATEDIRERROR","<b>ACHTUNG!</b>:&nbsp;folgende&nbsp;Sektion&nbsp;konnte&nbsp;nicht&nbsp;erstellt&nbsp;werden:&nbsp;");
define("_FDCHECKPERM","Schreibrechte&nbsp;&uuml;berpr&uuml;fen.");
define("_FDHIDDENSECT","versteckte&nbsp;Sektion");
define("_FDCHOOSESECTNAME","Name&nbsp;der&nbsp;Sektion&nbsp;eingeben:");
define("_FDCREATESUBSECT","Sektion&nbsp;erstellen&nbsp;in:&nbsp;");
define("_FDNOTWRITE","ist&nbsp;nicht&nbsp;beschreibbar!");


//upload file
define("_FDTOOBIG","<b>ACHTUNG!</b><br />Diese&nbsp;Datei&nbsp;wird&nbsp;nicht&nbsp;hochgeladen,&nbsp;da&nbsp;sie&nbsp;zu&nbsp;gross&nbsp;ist.");
define("_FDUPLOADOK","Datei&nbsp;erfolgreich&nbsp;hochgeladen.");
define("_FDUPLOADEXISTS","<b>ACHTUNG!</b>&nbsp;Im&nbsp;ausgew&auml;hlten&nbsp;Verzeichnis&nbsp;existiert&nbsp;bereits&nbsp;eine&nbsp;Datei&nbsp;mit&nbsp;diesem&nbsp;Namen.&nbsp;<br />&nbsp;Um&nbsp;diese&nbsp;Datei&nbsp;oder&nbsp;die&nbsp;zugeh&ouml;rige&nbsp;Beschreibung&nbsp;zu&nbsp;&auml;ndern&nbsp;bitte&nbsp;die&nbsp;<b>Bearbeitungsfunktion</b>&nbsp;nutzen.");
define("_FDFILENOTSELECT","Datei&nbsp;ausw&auml;hlen!");

//Alert
define("_FDDESCTOOLONG","<b>ACHTUNG!</b>&nbsp;Beschreibung&nbsp;zu&nbsp;lang.");
define("_FDNAMETOOLONG","<b>ACHTUNG!</b>&nbsp;Titel&nbsp;zu&nbsp;lang.");
define("_FDREDONLYDIR","<b>ACHTUNG:</b>&nbsp;bitte&nbsp;Schreibrechte&nbsp;f&uuml;r&nbsp;dieses&nbsp;Verzeichnis&nbsp;&uuml;berpr&uuml;fen.");
define("_FDERROR","<B>Fehler!</B>");

//error
define("_FDNONPUOI","<b>Aktion&nbsp;nicht&nbsp;erlaubt!</b>&nbsp;(Sichrheitsfehler.)<br />&nbsp;FDPlus:&nbsp;Zeile&nbsp;");
define("_FDERROR1","Die&nbsp;hochgeladene&nbsp;Datei&nbsp;ist&nbsp;gr&ouml;sser&nbsp;als&nbsp;die&nbsp;\"upload_max_filesize\"-Direktive&nbsp;in&nbsp;der&nbsp;php.ini.");
define("_FDERROR2","Die&nbsp;hochgeladene&nbsp;Datei&nbsp;ist&nbsp;gr&ouml;sser&nbsp;als&nbsp;die&nbsp;\"MAX_FILE_SIZE\"-Direktive&nbsp;im&nbsp;HTMLformular.");
define("_FDERROR3","Datei&nbsp;nur&nbsp;teilweise&nbsp;hochgeladen.");
define("_FDERROR4","Keine&nbsp;Datei&nbsp;hochgeladen.");
define("_FDERROR6","Tempor&auml;res&nbsp;Verzeichnis&nbsp;nicht&nbsp;vorhanden.");
define("_FDERROR7","Konnte&nbsp;Datei&nbsp;nicht&nbsp;speichern,&nbsp;Schreibvorgang&nbsp;fehlgeschlagen.");

//DOWNLOAD STATS
define("_FDSECT","Sektion");
define("_FDTOPSTATS","Download&nbsp;Statistiken");
//TOP DOWNLOAD
define("_FDTOPSTAT","Statistik");


?>

==> flatnuke_2.7.2.orig.tar.gz: flatnuke-2.7.2/languages/fd+lang/fd+de.php <==
<?
/**
/* FD+:German Translation
/*
/* German language file for FD+0.8
/* 
/* @author Aldo Boccacci <zorba_@tin.it> Author
/* @author Bjoern Splinter <Insites@gmail.com> Translator 
*/

//Benutzerinterface
define("_FDNAME","Name");
define("_FDSIZE","Gr&ouml;sse");
define("_FDDATE","Herausgekommen&nbsp;am");//need translation (new string="Date")
define("_FDVERSION", "Version");
define("_FDDESC","Beschreibung");
define("_FDHITS","Hits");
define("_FDDOWNLOAD","HERUNTERLADEN!");
define("_FDSTAT","Downloadstatistik");
define("_FDSTATTITLE","Downloadstatistik&nbsp;ansehen");
define("_FDDOWNLOADFILE","Datei&nbsp;herunterladen:&nbsp;");
define("_FDARCHIVEDIR","Archivverzeichnis");
/*define("_GOTOSECTION","Sektion&nbsp;ansehen");*/
define("_FDUPLOADER","Hochgeladen&nbsp;von");
define("_FDUPLOADERTITLE","Userprofil ansehen");
define("_FDSUMMARY","Summary");//need translation
define("_FDSUBDIRS","Subsections");//need translation
define("_FDRATING","Rating");//need translation
define("_FDRATEFILE","Rate this file");//need translation
define("_FDALREADYRATED","You have already rated this file!");//need translation
define("_FDVOTES","votes");//need translation
define("_FDTOVOTEAFILE","to vote a file");//need translation
define("_ENABLEVOTE","Enable vote");//need translation
//Datumsformat
define("_FDDATEFORMAT","d/m/Y H:i:s");

//gpg signatur
define("_FDGPGSIGN","GPG&nbsp;Signatur");
define("_FDGPGSIGNTITLE","GPG&nbsp;Signatur&nbsp;dieser&nbsp;Datei&nbsp;herunterladen:&nbsp;");
define("_FDDELETESIG","Signatur&nbsp;l&ouml;schen");

//screenshot
define("_FDDELETESCREEN","Delete screenshot");//need translation
define("_FDSCREENSHOT","Screenshot of the file: "); //need translation

//Administration
define("_FDARCHIVE","Archivieren");
define("_FDRESTORE","Wiederherstellen");
define("_FDEDIT","Bearbeiten");
define("_FDDELETE","L&ouml;schen");
define("_FDHIDE","Verstecken");
define("_FDSHOW","Zeigen");
define("_FDRENAME","Umbenennen");
define("_FDPUBLISH","Publish");//need translation
define("_FDADDFILE","Datei&nbsp;hinzuf&uuml;gen");

define("_FDARCHIVETITLE","Datei&nbsp;archivieren:&nbsp;");
define("_FDRESTORETITLE","Datei&nbsp;wiederherstellen:&nbsp;");
define("_FDEDITTITLE","Dateititel&nbsp;bearbeiten:&nbsp;");
define("_FDDELETETITLE","Datei&nbsp;l&ouml;schen:&nbsp;");
define("_FDHIDETITLE","Datei&nbsp;verstecken:&nbsp;");
define("_FDSHOWTITLE","Datei&nbsp;sichtbar&nbsp;machen:&nbsp;");
define("_FDRENAMETITLE","Datei&nbsp;umbenennen:&nbsp;");
define("_FDADDFILETITLE","Datei&nbsp;zu&nbsp;dieser&nbsp;Sektion&nbsp;hinzuf&uuml;gen.");
define("_FADMINPANEL","Admin panel");//need translazione
define("_FDALLOWUSERUPLOAD","Allow users to propose files in this section");//need translation

define("_FDBACK","Zur&uuml;ck");

//Edit/Add file
define("_FDRETURN","Return");
define("_FDEDITDESC","Dateibeschreibung&nbsp;bearbeiten:&nbsp;");
define("_FDEDITHEADER","Auf&nbsp;dieser&nbsp;Seite&nbsp;kannst&nbsp;Du&nbsp;die&nbsp;Beschreibung&nbsp;dieses&nbsp;Eintrags&nbsp;&auml;ndern.&nbsp;&Auml;nderungen&nbsp;werden&nbsp;gespeichert&nbsp;in:&nbsp;");
define("_FDEDITFOOTER","Du&nbsp;kannst&nbsp;auch&nbsp;die&nbsp;Datei&nbsp;selbst&nbsp;&auml;ndern.<br>Die&nbsp;neue&nbsp;Datei&nbsp;kann&nbsp;einen&nbsp;anderen&nbsp;Namen&nbsp;haben,&nbsp;fd+&nbsp;wird&nbsp;die&nbsp;zugeh&ouml;rige&nbsp;&nbsp;\".description\"&nbsp;automatisch&nbsp;&auml;ndern<br>&nbsp;und&nbsp;die&nbsp;alte&nbsp;Datei&nbsp;l&ouml;schen.");
define("_FDEDITSAVE", "&Auml;nderung&nbsp;speichern");
define("_FDEDITDONE", "&Auml;nderungen&nbsp;gespeichert");
define("_FDSHOWINBLOCKS","Show file in statistics blocks"); //need translation
define("_FDBLOCKS","Blocks"); //need translation
define("_FDUSERLABEL","Label"); //need translation
define("_FDUSERVALUE","Value"); //need translation
define("_FDUSERBOTH","Devono essere settati entrambi"); //need translation
define("_FDBASIC","Basic");//need translation
define("_FDADVANCED","Advanced");//need translation

//Rename File
define("_FDRENAMECHOOSE","Neuen&nbsp;Namen&nbsp;ausw&auml;hlen:&nbsp;");
define("_FDRENAMEEXTLIMIT","Die&nbsp;Dateierweiterung&nbsp;kann&nbsp;nicht&nbsp;ge&auml;ndert&nbsp;werden!.");
define("_FDRENAMEFILE","Die&nbsp;Datei&nbsp;");
define("_FDRENAMENOFD","ist&nbsp;keine&nbsp;FD+-Datei.");
define("_FDRENAMEOK","Umbenennen&nbsp;erfolgreich.");
define("_FDRENAMENOTCHANGED","Name&nbsp;nicht&nbsp;ge&auml;ndert.");
define("_FDRENAMEEXISTS1","Eine&nbsp;Datei&nbsp;mit&nbsp;Namen");
define("_FDRENAMEEXISTS2","ist&nbsp;im&nbsp;Verzeichnis&nbsp;bereits&nbsp;vorhanden!");
define("_FDRENAMECHANGENAME","Anderen&nbsp;Namen&nbsp;angeben.");
define("_FDRENAMEALERT","<b>ACHTUNG!</b>&nbsp;Datei&nbsp;kann&nbsp;nicht&nbsp;umbenannt&nbsp;werden");

//Delete file
define("_FDDELSURE","Bist&nbsp;Du&nbsp;sicher,&nbsp;dass&nbsp;Du&nbsp;folgende&nbsp;Dateien&nbsp;l&ouml;schen&nbsp;willst:&nbsp;");
define("_FDDEL", "L&ouml;schen");
define("_FDCANC", "Abbrechen");
define("_FDDELOK","Dateien&nbsp;gel&ouml;scht:&nbsp;");
define("_FDAND","und");

//Archive file
define("_FDARCHIVEOK","Datei&nbsp;archiviert.");
define("_FDARCHIVEGO","Zum&nbsp;Archivverzeichnis&nbsp;gehen.");
define("_FDRESTOREOK","Datei&nbsp;erfolgreich&nbsp;wiederhergestellt");
define("_FDARCHIVERETURN","zur&uuml;ck&nbsp;zur&nbsp;vorherigen&nbsp;Sektion");
define("_GOTOARCHIVEDIR","Zur&nbsp;Archivsektion&nbsp;gehen");

//Add file
define("_FDADDWHERE","Neue&nbsp;Datei&nbsp;zum&nbsp;Verzeichnis&nbsp;hinzuf&uuml;gen:&nbsp;");
define("_FDADDHEADER","Auf&nbsp;dieser&nbsp;Seite&nbsp;kannst&nbsp;Du&nbsp;eine&nbsp;neue&nbsp;Datei&nbsp;zum&nbsp;Verzeichnis&nbsp;hinzuf&uuml;gen");
define("_FDADDFOOTER","Eine&nbsp;Datei&nbsp;auf&nbsp;deinem&nbsp;Rechner&nbsp;ausw&auml;hlen.");
define("_NOTVALIDEXT","Die&nbsp;Erweiterung&nbsp;dieser&nbsp;Datei&nbsp;wird&nbsp;von&nbsp;FD+&nbsp;nicht&nbsp;unterst&uuml;tzt.&nbsp;Bitte&nbsp;f&uuml;ge&nbsp;zuerst&nbsp;diese&nbsp;Erweiterung&nbsp;zur&nbsp;Variable&nbsp;&#036;extensions&nbsp;in&nbsp;der&nbsp;Datei&nbsp;\"fd+.php\"&nbsp;hinzu");

//save file
define("_FDSAVESIZE","<b>ACHTUNG!</b>&nbsp;Dateigr&ouml;sse&nbsp;ist&nbsp;");

//move file
define("_FDMOVE","Verschieben");
define("_FDMOVEFILE","Datei&nbsp;verschieben&nbsp;");
define("_FDMOVEFILESECTION","&nbsp;nach&nbsp;Sektion");
define("_FDMOVELINK","(zum&nbsp;Verschieben&nbsp;auf&nbsp;die&nbsp;Verkn&uuml;pfung&nbsp;klicken)");
define("_FDMOVECONFIRM","Datei&nbsp;verschieben&nbsp;");
define("_FDMOVEFAIL","Verschieben&nbsp;der&nbsp;Datei&nbsp;nicht&nbsp;m&ouml;glich&nbsp;");
define("_FDMOVESUCCESS","erfolgreich&nbsp;verschoben");
define("_FDMOVETITLE","Folgende&nbsp;Datei&nbsp;verschieben:&nbsp;");
define("_FDDIR","Das&nbsp;Verzeichnis");


//creazione cartelle
define("_FDCREATESECTDOWNLOAD","Downloadsektion&nbsp;erzeugen");
define("_FDCREATESECT","Sektion&nbsp;erzeugen");
define("_FDCREATESECTOK","erfolgreich&nbsp;erzeugt!");
define("_FDCREATEONLYDIR","Sektion&nbsp;erzeugt,&nbsp;Datei&nbsp;section.php&nbsp;konnte&nbsp;aber&nbsp;nicht&nbsp;erstellt&nbsp;werden!");
define("_FDCREATEDIRERROR","<b>ACHTUNG!</b>:&nbsp;folgende&nbsp;Sektion&nbsp;konnte&nbsp;nicht&nbsp;erstellt&nbsp;werden:&nbsp;");
define("_FDCHECKPERM","Schreibrechte&nbsp;&uuml;berpr&uuml;fen.");
define("_FDHIDDENSECT","versteckte&nbsp;Sektion");
define("_FDCHOOSESECTNAME","Name&nbsp;der&nbsp;Sektion&nbsp;eingeben:");
define("_FDCREATESUBSECT","Sektion&nbsp;erstellen&nbsp;in:&nbsp;");
define("_FDNOTWRITE","ist&nbsp;nicht&nbsp;beschreibbar!");


//upload file
define("_FDTOOBIG","<b>ACHTUNG!</b><br>Diese&nbsp;Datei&nbsp;wird&nbsp;nicht&nbsp;hochgeladen,&nbsp;da&nbsp;sie&nbsp;zu&nbsp;gross&nbsp;ist.");
define("_FDUPLOADOK","Datei&nbsp;erfolgreich&nbsp;hochgeladen.");
define("_FDUPLOADEXISTS","<b>ACHTUNG!</b>&nbsp;Im&nbsp;ausgew&auml;hlten&nbsp;Verzeichnis&nbsp;existiert&nbsp;bereits&nbsp;eine&nbsp;Datei&nbsp;mit&nbsp;diesem&nbsp;Namen.&nbsp;<br>&nbsp;Um&nbsp;diese&nbsp;Datei&nbsp;oder&nbsp;die&nbsp;zugeh&ouml;rige&nbsp;Beschreibung&nbsp;zu&nbsp;&auml;ndern&nbsp;bitte&nbsp;die&nbsp;<b>Bearbeitungsfunktion</b>&nbsp;nutzen.");
define("_FDFILENOTSELECT","Datei&nbsp;ausw&auml;hlen!");

//Alert
define("_FDDESCTOOLONG","<b>ACHTUNG!</b>&nbsp;Beschreibung&nbsp;zu&nbsp;lang.");
define("_FDNAMETOOLONG","<b>ACHTUNG!</b>&nbsp;Titel&nbsp;zu&nbsp;lang.");
define("_FDREDONLYDIR","<b>ACHTUNG:</b>&nbsp;bitte&nbsp;Schreibrechte&nbsp;f&uuml;r&nbsp;dieses&nbsp;Verzeichnis&nbsp;&uuml;berpr&uuml;fen.");
define("_FDERROR","<B>Fehler!</B>");

//error
define("_FDNONPUOI","<b>Aktion&nbsp;nicht&nbsp;erlaubt!</b>&nbsp;(Sichrheitsfehler.)<br>");
define("_FDERROR1","Die&nbsp;hochgeladene&nbsp;Datei&nbsp;ist&nbsp;gr&ouml;sser&nbsp;als&nbsp;die&nbsp;\"upload_max_filesize\"-Direktive&nbsp;in&nbsp;der&nbsp;php.ini.");
define("_FDERROR2","Die&nbsp;hochgeladene&nbsp;Datei&nbsp;ist&nbsp;gr&ouml;sser&nbsp;als&nbsp;die&nbsp;\"MAX_FILE_SIZE\"-Direktive&nbsp;im&nbsp;HTMLformular.");
define("_FDERROR3","Datei&nbsp;nur&nbsp;teilweise&nbsp;hochgeladen.");
define("_FDERROR4","Keine&nbsp;Datei&nbsp;hochgeladen.");
define("_FDERROR6","Tempor&auml;res&nbsp;Verzeichnis&nbsp;nicht&nbsp;vorhanden.");
define("_FDERROR7","Konnte&nbsp;Datei&nbsp;nicht&nbsp;speichern,&nbsp;Schreibvorgang&nbsp;fehlgeschlagen.");

//DOWNLOAD STATS
define("_FDSECT","Sektion");
define("_FDTOPSTATS","Download&nbsp;Statistiken");
//TOP DOWNLOAD
define("_FDTOPSTAT","Statistik");

//remote file/url
define("_FDADDURL","Add remote file"); //need translation
define("_FDCHOOSEURL","Specify the url of the file:"); //need translation

//FDuser
define("_FDWAITFORADMIN","The file will not be immediately visible. Wait for site's administrator approval."); //need translation
define("_FDLIMIT","Raggiunto il limite massimo di file proponibili.<br> Attendi che l'amministratore pubblichi i file in attesa di approvazione."); //need translation
define("_FDPUBLISHFILES","Publish files"); //need translation
define("_FDPROPOSE","Propose a file");//need translation
define("_FDWAITINGFILES","files waiting validation");//need translation
?>
